@@ -71,6 +71,16 @@ var pluralForms = map[string]func(n int) int{
 		}
 		return 0
 	},
+	// nplurals=3; plural=(n==1 ? 0 : n==0 || (n%100 > 0 && n%100 < 20) ? 1 : 2);
+	"ro_RO": func(n int) int {
+		switch {
+		case n == 1:
+			return 0
+		case n == 0 || (n%100 > 0 && n%100 < 20):
+			return 1
+		}
+		return 2
+	},
 	"ru_RU": pluralFormRuSrUa,
 	// nplurals=2; plural=(n > 1);
 	"tr_TR": func(n int) int {
